SERV user manual
================

Welcome to the user manual of the award-winning SERV, the world's smallest RISC-V CPU.

.. toctree::
   :maxdepth: 3
   :caption: Contents:

   interface.rst
   modules.rst
